@@ -20,51 +20,50 @@
 
 #include "kompare_part.h"
 
-#include <QtGui/QLayout>
-#include <QtGui/QWidget>
+#include <QDialog>
+#include <QLayout>
+#include <QWidget>
 #include <QPainter>
 #include <QPrinter>
 #include <QPrintDialog>
 #include <QPrintPreviewDialog>
+#include <QTemporaryDir>
+#include <QTemporaryFile>
 
 #include <kaboutdata.h>
-#include <kaction.h>
 #include <kactioncollection.h>
-#include <kapplication.h>
-#include <kcomponentdata.h>
-#include <kdebug.h>
-#include <kdeprintdialog.h>
-#include <kfiledialog.h>
-#include <klocale.h>
+#include <kjobwidgets.h>
+#include <klocalizedstring.h>
 #include <kmessagebox.h>
+#include <kpluginfactory.h>
+#include <ksharedconfig.h>
 #include <kstandardaction.h>
-#include <kstandarddirs.h>
 #include <kstandardshortcut.h>
-#include <ktemporaryfile.h>
-#include <ktempdir.h>
 
-#include <kio/netaccess.h>
-#include <kglobal.h>
+#include <kio/copyjob.h>
+#include <kio/statjob.h>
+#include <kio/filecopyjob.h>
+#include <kio/mkdirjob.h>
 
-#include "diffmodel.h"
+#include <diffmodel.h>
 #include "komparelistview.h"
 #include "kompareconnectwidget.h"
-#include "diffsettings.h"
+#include <diffsettings.h>
 #include "viewsettings.h"
 #include "kompareprefdlg.h"
 #include "komparesaveoptionswidget.h"
 #include "komparesplitter.h"
 #include "kompareview.h"
 
+Q_LOGGING_CATEGORY(KOMPAREPART, "komparepart")
+
 K_PLUGIN_FACTORY( KomparePartFactory, registerPlugin<KomparePart>(); )
-K_EXPORT_PLUGIN( KomparePartFactory )
 
 ViewSettings* KomparePart::m_viewSettings = 0L;
 DiffSettings* KomparePart::m_diffSettings = 0L;
 
 KomparePart::KomparePart( QWidget *parentWidget, QObject *parent, const QVariantList & /*args*/ ) :
 	KParts::ReadWritePart(parent),
-	m_tempDiff( 0 ),
 	m_info()
 {
 	if( !m_viewSettings ) {
@@ -74,7 +73,7 @@ KomparePart::KomparePart( QWidget *parentWidget, QObject *parent, const QVariant
 		m_diffSettings = new DiffSettings( 0 );
 	}
 
-	readProperties( KGlobal::config().data() );
+	readProperties( KSharedConfig::openConfig().data() );
 
 	m_view = new KompareView ( m_viewSettings, parentWidget );
 	setWidget( m_view );
@@ -171,7 +170,7 @@ void KomparePart::setupActions()
 	// create our actions
 
 	m_saveAll = actionCollection()->addAction("file_save_all", this, SLOT(saveAll()));
-	m_saveAll->setIcon(KIcon("document-save-all"));
+	m_saveAll->setIcon(QIcon::fromTheme("document-save-all"));
 	m_saveAll->setText(i18n("Save &All"));
 	m_saveDiff = actionCollection()->addAction("file_save_diff", this, SLOT(saveDiff()));
 	m_saveDiff->setText(i18n("Save &Diff..."));
@@ -180,9 +179,9 @@ void KomparePart::setupActions()
 	m_diffStats = actionCollection()->addAction("file_diffstats", this, SLOT(slotShowDiffstats()));
 	m_diffStats->setText(i18n("Show Statistics"));
 	m_diffRefresh = actionCollection()->addAction("file_refreshdiff", this, SLOT(slotRefreshDiff()));
-	m_diffRefresh->setIcon(KIcon("view-refresh"));
+	m_diffRefresh->setIcon(QIcon::fromTheme("view-refresh"));
 	m_diffRefresh->setText(i18n("Refresh Diff"));
-	m_diffRefresh->setShortcut(KStandardShortcut::reload());
+	m_diffRefresh->setShortcuts(KStandardShortcut::reload());
 
 	m_print        = actionCollection()->addAction(KStandardAction::Print, this, SLOT( slotFilePrint() ));
 	m_printPreview = actionCollection()->addAction(KStandardAction::PrintPreview, this, SLOT( slotFilePrintPreview() ));
@@ -202,13 +201,13 @@ void KomparePart::updateActions()
 
 void KomparePart::setEncoding( const QString& encoding )
 {
-	kDebug(8103) << "Encoding: " << encoding << endl;
+	qCDebug(KOMPAREPART) << "Encoding: " << encoding;
 	m_modelList->setEncoding( encoding );
 }
 
-bool KomparePart::openDiff( const KUrl& url )
+bool KomparePart::openDiff( const QUrl& url )
 {
-	kDebug(8103) << "Url = " << url.url() << endl;
+	qCDebug(KOMPAREPART) << "Url = " << url.url();
 
 	m_info.mode = Kompare::ShowingDiff;
 	m_info.source = url;
@@ -219,7 +218,7 @@ bool KomparePart::openDiff( const KUrl& url )
 
 	if ( !m_info.localSource.isEmpty() )
 	{
-		kDebug(8103) << "Download succeeded " << endl;
+		qCDebug(KOMPAREPART) << "Download succeeded ";
 		result = m_modelList->openDiff( m_info.localSource );
 		updateActions();
 		updateCaption();
@@ -227,7 +226,7 @@ bool KomparePart::openDiff( const KUrl& url )
 	}
 	else
 	{
-		kDebug(8103) << "Download failed !" << endl;
+		qCDebug(KOMPAREPART) << "Download failed !";
 	}
 
 	return result;
@@ -252,18 +251,18 @@ bool KomparePart::openDiff( const QString& diffOutput )
 	return value;
 }
 
-bool KomparePart::openDiff3( const KUrl& diff3Url )
+bool KomparePart::openDiff3( const QUrl& diff3Url )
 {
 	// FIXME: Implement this !!!
-	kDebug(8103) << "Not implemented yet. Filename is: " << diff3Url.prettyUrl() << endl;
+	qCDebug(KOMPAREPART) << "Not implemented yet. Filename is: " << diff3Url;
 	return false;
 }
 
 bool KomparePart::openDiff3( const QString& diff3Output )
 {
 	// FIXME: Implement this !!!
-	kDebug(8103) << "Not implemented yet. diff3 output is: " << endl;
-	kDebug(8103) << diff3Output << endl;
+	qCDebug(KOMPAREPART) << "Not implemented yet. diff3 output is: ";
+	qCDebug(KOMPAREPART) << diff3Output;
 	return false;
 }
 
@@ -273,63 +272,76 @@ bool KomparePart::exists( const QString& url )
 	return fi.exists();
 }
 
-bool KomparePart::fetchURL( const KUrl& url, bool addToSource )
+bool KomparePart::fetchURL( const QUrl& url, bool addToSource )
 {
 	// Default value if there is an error is "", we rely on it!
 	QString tempFileName( "" );
 	// Only in case of error do we set result to false, don't forget!!
 	bool result = true;
-	KTempDir* tmpDir = 0;
+	QTemporaryDir* tmpDir = 0;
 
 	if ( !url.isLocalFile() )
 	{
-		KIO::UDSEntry node;
-		KIO::NetAccess::stat( url, node, widget() );
-		if ( !node.isDir() )
-		{
-			if ( ! KIO::NetAccess::download( url, tempFileName, widget() ) )
-			{
-				slotShowError( i18n( "<qt>The URL <b>%1</b> cannot be downloaded.</qt>", url.prettyUrl() ) );
-				tempFileName = ""; // Not sure if download has already touched this tempFileName when there is an error
-				result = false;
-			}
-		}
-		else
-		{
-			tmpDir = new KTempDir(KStandardDirs::locateLocal("tmp", "kompare"));
-			tmpDir->setAutoRemove( true ); // Yes this is the default but just to make sure
-			if ( ! KIO::NetAccess::dircopy( url, KUrl( tmpDir->name() ), widget() ) )
-			{
-				slotShowError( i18n( "<qt>The URL <b>%1</b> cannot be downloaded.</qt>", url.prettyUrl() ) );
-				delete tmpDir;
-				tmpDir = 0;
-				result = false;
-			}
-			else
-			{
-				tempFileName = tmpDir->name();
-				kDebug(8101) << "tempFileName = " << tempFileName << endl;
-				// If a directory is copied into KTempDir then the directory in 
-				// here is what I need to add to tempFileName
-				QDir dir( tempFileName );
-				QStringList entries = dir.entryList( QDir::Dirs | QDir::NoDotAndDotDot );
-				if ( entries.size() == 1 ) // More than 1 entry in here means big problems!!!
-				{
-					if ( !tempFileName.endsWith( '/' ) )
-						tempFileName += '/';
-					tempFileName += entries.at( 0 );
-					tempFileName += '/';
-				}
-				else
-				{
-					kDebug(8101) << "Yikes, nothing downloaded?" << endl;
-					delete tmpDir;
-					tmpDir = 0;
-					tempFileName = "";
-					result = false;
-				}
-			}
-		}
+        KIO::StatJob *statJob = KIO::stat( url );
+        KJobWidgets::setWindow( statJob, widget() );
+        if (statJob->exec() )
+        {
+            KIO::UDSEntry node;
+            node = statJob->statResult();
+            if ( !node.isDir() )
+            {
+                tmpDir = new QTemporaryDir(QDir::tempPath() + "/kompare");
+                tmpDir->setAutoRemove( true );
+                tempFileName = tmpDir->path() + QLatin1Char('/') + url.fileName();
+                KIO::FileCopyJob* copyJob = KIO::file_copy( url, QUrl::fromLocalFile( tempFileName ) );
+                KJobWidgets::setWindow( copyJob, widget() );
+                if ( ! copyJob->exec() )
+                {
+                    qDebug() << "download error " << copyJob->errorString();
+                    slotShowError( i18n( "<qt>The URL <b>%1</b> cannot be downloaded.</qt>", url.toDisplayString() ) );
+                    tempFileName = ""; // Not sure if download has already touched this tempFileName when there is an error
+                    result = false;
+                }
+            }
+            else
+            {
+                tmpDir = new QTemporaryDir(QDir::tempPath() + "/kompare");
+                tmpDir->setAutoRemove( true ); // Yes this is the default but just to make sure
+                KIO::CopyJob *copyJob = KIO::copy( url, QUrl::fromLocalFile( tmpDir->path() ));
+                KJobWidgets::setWindow( copyJob, widget() );
+                if ( ! copyJob->exec() )
+                {
+                    slotShowError( i18n( "<qt>The URL <b>%1</b> cannot be downloaded.</qt>", url.toDisplayString() ) );
+                    delete tmpDir;
+                    tmpDir = 0;
+                    result = false;
+                }
+                else
+                {
+                    tempFileName = tmpDir->path();
+                    qCDebug(KOMPAREPART) << "tempFileName = " << tempFileName;
+                    // If a directory is copied into QTemporaryDir then the directory in
+                    // here is what I need to add to tempFileName
+                    QDir dir( tempFileName );
+                    QStringList entries = dir.entryList( QDir::Dirs | QDir::NoDotAndDotDot );
+                    if ( entries.size() == 1 ) // More than 1 entry in here means big problems!!!
+                    {
+                        if ( !tempFileName.endsWith( '/' ) )
+                            tempFileName += '/';
+                        tempFileName += entries.at( 0 );
+                        tempFileName += '/';
+                    }
+                    else
+                    {
+                        qCDebug(KOMPAREPART) << "Yikes, nothing downloaded?";
+                        delete tmpDir;
+                        tmpDir = 0;
+                        tempFileName = "";
+                        result = false;
+                    }
+                }
+            }
+        }
 	}
 	else
 	{
@@ -338,7 +350,7 @@ bool KomparePart::fetchURL( const KUrl& url, bool addToSource )
 			tempFileName = url.toLocalFile();
 		else
 		{
-			slotShowError( i18n( "<qt>The URL <b>%1</b> does not exist on your system.</qt>", url.prettyUrl() ) );
+			slotShowError( i18n( "<qt>The URL <b>%1</b> does not exist on your system.</qt>", url.toDisplayString() ) );
 			result = false;
 		}
 	}
@@ -346,12 +358,12 @@ bool KomparePart::fetchURL( const KUrl& url, bool addToSource )
 	if ( addToSource )
 	{
 		m_info.localSource = tempFileName;
-		m_info.sourceKTempDir = tmpDir;
+		m_info.sourceQTempDir = tmpDir;
 	}
 	else
 	{
 		m_info.localDestination = tempFileName;
-		m_info.destinationKTempDir = tmpDir;
+		m_info.destinationQTempDir = tmpDir;
 	}
 
 	return result;
@@ -359,37 +371,33 @@ bool KomparePart::fetchURL( const KUrl& url, bool addToSource )
 
 void KomparePart::cleanUpTemporaryFiles()
 {
-	kDebug(8101) << "Cleaning temporary files." << endl;
+	qCDebug(KOMPAREPART) << "Cleaning temporary files.";
 	if ( !m_info.localSource.isEmpty() )
 	{
-		if ( m_info.sourceKTempDir == 0 )
-			KIO::NetAccess::removeTempFile( m_info.localSource );
-		else
+		if ( m_info.sourceQTempDir != 0 )
 		{
-			delete m_info.sourceKTempDir;
-			m_info.sourceKTempDir = 0;
+			delete m_info.sourceQTempDir;
+			m_info.sourceQTempDir = 0;
 		}
 		m_info.localSource = "";
 	}
 	if ( !m_info.localDestination.isEmpty() )
 	{
-		if ( m_info.destinationKTempDir == 0  )
-			KIO::NetAccess::removeTempFile( m_info.localDestination );
-		else
+		if ( m_info.destinationQTempDir != 0  )
 		{
-			delete m_info.destinationKTempDir;
-			m_info.destinationKTempDir = 0;
+			delete m_info.destinationQTempDir;
+			m_info.destinationQTempDir = 0;
 		}
 		m_info.localDestination = "";
 	}
 }
 
-void KomparePart::compare( const KUrl& source, const KUrl& destination )
+void KomparePart::compare( const QUrl& source, const QUrl& destination )
 {
 	// FIXME: This is silly, i can use NetAccess::stat to figure out what it is and not
 	// wait until i am in the modellist to determine the mode we're supposed to be in.
 	// That should make the code more readable
-	// I should store the KTempDir(s)/File(s) in the Info struct as well and delete it at the right time
+	// I should store the QTemporaryDir(s)/File(s) in the Info struct as well and delete it at the right time
 	m_info.source = source;
 	m_info.destination = destination;
 
@@ -403,37 +411,37 @@ void KomparePart::compare( const KUrl& source, const KUrl& destination )
 	compareAndUpdateAll();
 }
 
-void KomparePart::compareFileString( const KUrl & sourceFile, const QString & destination)
+void KomparePart::compareFileString( const QUrl & sourceFile, const QString & destination)
 {
 	//Set the modeto specify that the source is a file, and the destination is a string
 	m_info.mode = Kompare::ComparingFileString;
-	
+
 	m_info.source = sourceFile;
 	m_info.localDestination = destination;
-	
+
 	fetchURL(sourceFile, true);
-	
+
 	emit kompareInfo( &m_info );
-	
+
 	compareAndUpdateAll();
 }
 
-void KomparePart::compareStringFile( const QString & source, const KUrl & destinationFile)
+void KomparePart::compareStringFile( const QString & source, const QUrl & destinationFile)
 {
 	//Set the modeto specify that the source is a file, and the destination is a string
 	m_info.mode = Kompare::ComparingStringFile;
-	
+
 	m_info.localSource = source;
 	m_info.destination = destinationFile;
-	
+
 	fetchURL(destinationFile, false);
-	
+
 	emit kompareInfo( &m_info );
-	
+
 	compareAndUpdateAll();
 }
 
-void KomparePart::compareFiles( const KUrl& sourceFile, const KUrl& destinationFile )
+void KomparePart::compareFiles( const QUrl& sourceFile, const QUrl& destinationFile )
 {
 	m_info.mode = Kompare::ComparingFiles;
 
@@ -450,7 +458,7 @@ void KomparePart::compareFiles( const KUrl& sourceFile, const KUrl& destinationF
 	compareAndUpdateAll();
 }
 
-void KomparePart::compareDirs( const KUrl& sourceDirectory, const KUrl& destinationDirectory )
+void KomparePart::compareDirs( const QUrl& sourceDirectory, const QUrl& destinationDirectory )
 {
 	m_info.mode = Kompare::ComparingDirs;
 
@@ -465,7 +473,7 @@ void KomparePart::compareDirs( const KUrl& sourceDirectory, const KUrl& destinat
 	compareAndUpdateAll();
 }
 
-void KomparePart::compare3Files( const KUrl& /*originalFile*/, const KUrl& /*changedFile1*/, const KUrl& /*changedFile2*/ )
+void KomparePart::compare3Files( const QUrl& /*originalFile*/, const QUrl& /*changedFile1*/, const QUrl& /*changedFile2*/ )
 {
 	// FIXME: actually implement this some day :)
 	updateActions();
@@ -473,7 +481,7 @@ void KomparePart::compare3Files( const KUrl& /*originalFile*/, const KUrl& /*cha
 	updateStatus();
 }
 
-void KomparePart::openFileAndDiff( const KUrl& file, const KUrl& diffFile )
+void KomparePart::openFileAndDiff( const QUrl& file, const QUrl& diffFile )
 {
 	m_info.source = file;
 	m_info.destination = diffFile;
@@ -487,7 +495,7 @@ void KomparePart::openFileAndDiff( const KUrl& file, const KUrl& diffFile )
 	compareAndUpdateAll();
 }
 
-void KomparePart::openDirAndDiff ( const KUrl& dir,  const KUrl& diffFile )
+void KomparePart::openDirAndDiff ( const QUrl& dir,  const QUrl& diffFile )
 {
 	m_info.source = dir;
 	m_info.destination = diffFile;
@@ -527,29 +535,31 @@ bool KomparePart::saveAll()
 
 void KomparePart::saveDiff()
 {
-	KDialog dlg( widget() );
+	QDialog dlg( widget() );
 	dlg.setObjectName( "save_options" );
 	dlg.setModal( true );
 	dlg.setWindowTitle( i18n("Diff Options") );
-	dlg.setButtons( KDialog::Ok|KDialog::Cancel );
+	QDialogButtonBox *buttons = new QDialogButtonBox( QDialogButtonBox::Save | QDialogButtonBox::Cancel, &dlg );
 	KompareSaveOptionsWidget* w = new KompareSaveOptionsWidget(
 	                                             m_info.localSource,
 	                                             m_info.localDestination,
 	                                             m_diffSettings, &dlg );
-	dlg.setMainWidget( w );
-	dlg.setButtonGuiItem( KDialog::Ok, KStandardGuiItem::save() );
+	QHBoxLayout *layout = new QHBoxLayout(&dlg);
+	layout->addWidget( w );
+	dlg.setLayout( layout );
 
 	if( dlg.exec() ) {
 		w->saveOptions();
-		KSharedConfig::Ptr config = componentData().config();
+		KSharedConfig::Ptr config = KSharedConfig::openConfig();
 		saveProperties( config.data() );
 		config->sync();
 
 		while ( 1 )
 		{
-			KUrl url = KFileDialog::getSaveUrl( m_info.destination.url(),
-			              i18n("*.diff *.dif *.patch|Patch Files"), widget(), i18n( "Save .diff" ) );
-			if ( KIO::NetAccess::exists( url, KIO::NetAccess::DestinationSide, widget() ) )
+			QUrl url = QFileDialog::getSaveFileUrl( widget(), i18n( "Save .diff" ),
+                                                    m_info.destination.url(),
+                                                    i18n("Patch Files (*.diff *.dif *.patch)") );
+			if ( QFile::exists( url.toLocalFile() ) )
 			{
 				int result = KMessageBox::warningYesNoCancel( widget(), i18n("The file exists or is write-protected; do you want to overwrite it?"), i18n("File Exists"), KGuiItem(i18n("Overwrite")), KGuiItem(i18n("Do Not Overwrite")) );
 				if ( result == KMessageBox::Cancel )
@@ -562,9 +572,9 @@ void KomparePart::saveDiff()
 				}
 				else
 				{
-					kDebug(8103) << "URL = " << url.prettyUrl() << endl;
-					kDebug(8103) << "Directory = " << w->directory() << endl;
-					kDebug(8103) << "DiffSettings = " << m_diffSettings << endl;
+					qCDebug(KOMPAREPART) << "URL = " << url.toDisplayString();
+					qCDebug(KOMPAREPART) << "Directory = " << w->directory();
+					qCDebug(KOMPAREPART) << "DiffSettings = " << m_diffSettings;
 
 					m_modelList->saveDiff( url.url(), w->directory(), m_diffSettings );
 					break;
@@ -572,9 +582,9 @@ void KomparePart::saveDiff()
 			}
 			else
 			{
-				kDebug(8103) << "URL = " << url.prettyUrl() << endl;
-				kDebug(8103) << "Directory = " << w->directory() << endl;
-				kDebug(8103) << "DiffSettings = " << m_diffSettings << endl;
+				qCDebug(KOMPAREPART) << "URL = " << url.toDisplayString();
+				qCDebug(KOMPAREPART) << "Directory = " << w->directory();
+				qCDebug(KOMPAREPART) << "DiffSettings = " << m_diffSettings;
 
 				m_modelList->saveDiff( url.url(), w->directory(), m_diffSettings );
 				break;
@@ -587,7 +597,7 @@ void KomparePart::slotFilePrint()
 {
 	QPrinter printer;
 	printer.setOrientation( QPrinter::Landscape );
-	QPrintDialog* dlg = KdePrint::createPrintDialog( &printer, m_splitter );
+	QPrintDialog* dlg = new QPrintDialog( &printer, 0 );
 
 	if ( dlg->exec() == QDialog::Accepted )
 	{
@@ -611,30 +621,30 @@ void KomparePart::slotFilePrintPreview()
 
 void KomparePart::slotPaintRequested( QPrinter* printer )
 {
-	kDebug(8103) << "Now paint something..." << endl;
+	qCDebug(KOMPAREPART) << "Now paint something...";
 	QPainter p;
 	p.begin( printer );
 
 	QSize widgetWidth = m_view->size();
-	kDebug(8103) << "printer.width()     = " << printer->width() << endl;
-	kDebug(8103) << "widgetWidth.width() = " << widgetWidth.width() << endl;
+	qCDebug(KOMPAREPART) << "printer.width()     = " << printer->width();
+	qCDebug(KOMPAREPART) << "widgetWidth.width() = " << widgetWidth.width();
 	qreal factor = ((qreal)printer->width())/((qreal)widgetWidth.width());
 
-	kDebug(8103) << "factor              = " << factor << endl;
+	qCDebug(KOMPAREPART) << "factor              = " << factor;
 
 	p.scale( factor, factor );
 	m_view->render( &p );
 
 	p.end();
-	kDebug(8103) << "Done painting something..." << endl;
+	qCDebug(KOMPAREPART) << "Done painting something...";
 }
 
 KAboutData* KomparePart::createAboutData()
 {
-    KAboutData *about = new KAboutData("kompare", 0, ki18n("KomparePart"), "4.0");
-    about->addAuthor(ki18n("John Firebaugh"), ki18n("Author"), "jfirebaugh@kde.org");
-    about->addAuthor(ki18n("Otto Bruggeman"), ki18n("Author"), "bruggie@gmail.com" );
-    about->addAuthor(ki18n("Kevin Kofler"), ki18n("Author"), "kevin.kofler@chello.at" );
+    KAboutData *about = new KAboutData("kompare", i18n("KomparePart"), "4.0");
+    about->addAuthor(i18n("John Firebaugh"), i18n("Author"), "jfirebaugh@kde.org");
+    about->addAuthor(i18n("Otto Bruggeman"), i18n("Author"), "bruggie@gmail.com" );
+    about->addAuthor(i18n("Kevin Kofler"), i18n("Author"), "kevin.kofler@chello.at" );
     return about;
 }
 
@@ -663,8 +673,8 @@ void KomparePart::slotSetStatus( enum Kompare::Status status )
 
 void KomparePart::updateCaption()
 {
-	QString source = m_info.source.prettyUrl();
-	QString destination = m_info.destination.prettyUrl();
+	QString source = m_info.source.toDisplayString();
+	QString destination = m_info.destination.toDisplayString();
 
 	QString text;
 
@@ -688,8 +698,8 @@ void KomparePart::updateCaption()
 
 void KomparePart::updateStatus()
 {
-	QString source = m_info.source.prettyUrl();
-	QString destination = m_info.destination.prettyUrl();
+	QString source = m_info.source.toDisplayString();
+	QString destination = m_info.destination.toDisplayString();
 
 	QString text;
 
@@ -715,8 +725,8 @@ void KomparePart::updateStatus()
 		break;
 	case Kompare::BlendingDir :
 		text = i18n( "Blending diff output from %1 into folder %2" ,
-		      m_info.source.prettyUrl() ,
-		      m_info.destination.prettyUrl() );
+		      m_info.source.toDisplayString() ,
+		      m_info.destination.toDisplayString() );
 		break;
 	default:
 		break;
@@ -735,14 +745,14 @@ void KomparePart::compareAndUpdateAll()
 		case Kompare::UnknownMode:
 			m_modelList->compare();
 			break;
-		
+
 		case Kompare::ComparingStringFile:
 		case Kompare::ComparingFileString:
 		case Kompare::ComparingFiles:
 		case Kompare::ComparingDirs:
 			m_modelList->compare(m_info.mode);
 			break;
-			
+
 		case Kompare::BlendingFile:
 			m_modelList->openFileAndDiff();
 			break;
